/*
    --------------------------------------------------------------------------
    Code for link-hover text boxes
    By Nicolas Hoening
    Usage: <a onmouseover="popup('popup content', width)">a link</a>
     (width is optional - default is in CSS: #pup {width: x;},
      escape " in content with &quot;)
    Tutorial and support at http://nicolashoening.de?twocents&nr=8
    --------------------------------------------------------------------------

	Modified to allow parameters for BACKGROUND, COLOUR, FONT SIZE & FONT NAME
	Philip Bolt, 29/10/12
	Updated for default values, 10/11/12
	Updated for closure on 'click;, 12/11/12
	Parameters are now msg, width, bkg, col, f_sz, f_nme
	
	Trailing parameters can just be ommitted but any others must have 2 quotes entered.
	
	I've also added a section to be used with the 'click' event. Without it, if a link is clicked, the pop-up is still there when you
	go back to the original page.
	*/
var minMargin = 15; // set how much minimal space there should be (in pixels)
                    // between the popup and everything else (borders, mouse)
var ready = false;  // we are ready when the mouse event is set up
var default_width = 200; // will be set to width from css in document.ready

/*Defaults used to reset the display*/
var default_bkg;
var default_col;
var default_f_sz;
var default_f_nme;

/* Prepare popup and define the mouseover callback */
	jQuery(document).ready(function(){
	$('body').append('<div id="pup" style="position:abolute; display:none; z-index:200;"></div>');

    css_width = $('#pup').width();
	
    if (css_width != 0) default_width = css_width;
	
    // set dynamic coords when the mouse moves
    $(document).mousemove(function(e)
		{ 
        var x,y;
      
        x = $(document).scrollLeft() + e.clientX;
        y = $(document).scrollTop() + e.clientY;

        x += 10; // important: if the popup is where the mouse is, the hoverOver/hoverOut events flicker
      
        var x_y = nudge(x,y); // avoids edge overflow

        // remember: the popup is still hidden
        $('#pup').css('top', x_y[1] + 'px');
        $('#pup').css('left', x_y[0] + 'px');
		});
    ready = true;
	//Store the default values
	default_bkg=$('#pup').css('background-color');
	default_col=$('#pup').css('color');
	default_f_sz=$('#pup').css('font-size');
	default_f_nme$('#pup').css('font-family');
	});

/*
 The actual callback:
 Write message, show popup w/ custom width if necessary,
 make sure it disappears on mouseout
*/
function popup(msg, width, bkg, col, f_sz, f_nme)
	{
    if (ready) {
        // use default width if not customized here
        if (typeof width === "undefined"){
            width = default_width;
        }
		
		if (typeof bkg !="undefined")				//If there's a BACKGROUND value,
			{
			$('#pup').css('background-color', bkg);	//use it.
			}
			else											//Otherwise,
			{
			$('#pup').css('background-color', default_bkg);	//use the default to clear any previous setting.
			}
		
		if (typeof col !="undefined")		//If there's a COLOUR value,
			{
            $('#pup').css('color', col);	//use it.
			}
			else									//Otherwise,
			{
			$('#pup').css('color', default_col);	//use the default.
			}
		
		if (typeof f_sz !="undefined")			//If there's a FONT SIZE,
			{
            $('#pup').css('font-size', f_sz);	//use it.
			}
			else										//Otherwise,
			{
			$('#pup').css('font-size', default_f_sz);	//use the default.
			}
		
		if (typeof f_nme !="undefined")				//If there's a FONT FAMILY quoted,
			{
			$('#pup').css('font-family', f_nme);	//use it.
			}
			else											//Otherwise,
			{
			$('#pup').css('font-family', default_f_nme);	//use the default.
			}
		
        // Write content and display
        $('#pup').html(msg).width(width).show();
        // Make sure popup goes away on 'mouseout' and after a 'click' event.
        // The event obj needs to be gotten from the virtual  
        // caller, since we use onmouseover='popup(msg)' 
        var t = getTarget(arguments.callee.caller.arguments[0]);
        $(t).unbind('click').bind('click',function(e)
			{
            $('#pup').hide().width(default_width);
            }
        );
		 
		$(t).unbind('mouseout').bind('mouseout',function(e)
			{
            $('#pup').hide().width(default_width);
            }
        );
    }
}

/* Avoid edge overflow */
function nudge(x,y)
{
    var win = $(window);
    
    // When the mouse is too far on the right, put window to the left
    var xtreme = $(document).scrollLeft() + win.width() - $('#pup').width() - minMargin;
    if(x > xtreme) {
        x -= $('#pup').width() + 2 * minMargin;
    }
    x = max(x, 0);

    // When the mouse is too far down, move window up
    if((y + $('#pup').height()) > (win.height() +  $(document).scrollTop())) {
        y -= $('#pup').height() + minMargin;
    }

    return [ x, y ];
}

/* custom max */
function max(a,b){
    if (a>b) return a;
    else return b;
}

/*
 Get the target (element) of an event.
 Inspired by quirksmode
*/
function getTarget(e) {
    var targ;
    if (!e) var e = window.event;
    if (e.target) targ = e.target;
    else if (e.srcElement) targ = e.srcElement;
    if (targ.nodeType == 3) // defeat Safari bug
        targ = targ.parentNode;
    return targ;
}
